Index: trunk/ippTools/src/pztool.c
===================================================================
--- trunk/ippTools/src/pztool.c	(revision 17655)
+++ trunk/ippTools/src/pztool.c	(revision 17700)
@@ -250,5 +250,5 @@
 
     // negative simple so the default is true
-    if (!ippdbPrintMetadatas(stdout, output, "pzPendingExp", !simple)) {
+    if (!ippdbPrintMetadatas(stdout, output, "pzDownloadExp", !simple)) {
         psError(PS_ERR_UNKNOWN, false, "failed to print array");
         psFree(output);
@@ -337,5 +337,5 @@
 
     // negative simple so the default is true
-    if (!ippdbPrintMetadatas(stdout, output, "pzPendingImfile", !simple)) {
+    if (!ippdbPrintMetadatas(stdout, output, "pzDownloadImfile", !simple)) {
         psError(PS_ERR_UNKNOWN, false, "failed to print array");
         psFree(output);

Index: trunk/ippTools/src/pzgetimfiles.c
===================================================================
--- trunk/ippTools/src/pzgetimfiles.c	(revision 17655)
+++ trunk/ippTools/src/pzgetimfiles.c	(revision 17700)
@@ -143,8 +143,8 @@
         }
 
         // remove the pzPendingExp entry for this exp (fileset)
         {
             char *query = 
-                "DELETE FROM pzPendingExp"
+                "DELETE FROM pzDownloadExp"
                 " WHERE"
                 "   exp_name = '%s'"
@@ -143,8 +143,8 @@
         }
 
-        // remove the pzPendingExp entry for this exp (fileset)
+        // remove the pzDownloadExp entry for this exp (fileset)
         {
             char *query = 